\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{L-SIMIA}[2024/06/02 Letters of Solar Influences on the Magnetosphere, Ionosphere and Atmosphere class]

\LoadClass[a4paper, 10pt, twoside]{article} % Set font size to 10pt

% Packages
\RequirePackage{graphicx}
\RequirePackage{geometry}
\RequirePackage{fancyhdr}
\RequirePackage{titlesec}
\RequirePackage{multicol}
\RequirePackage{amsmath}
\RequirePackage{float} % for the H float option
\RequirePackage{lipsum} % for dummy text
\RequirePackage{etoolbox}

% Page layout
\geometry{left=2cm, right=2cm, top=1in, bottom=1in}
\setlength{\columnsep}{0.25in}

% Header and Footer
\setlength{\headheight}{14pt} % Adjust head height to avoid warnings
\pagestyle{fancy}
\fancyhf{}
\fancyhead[LE,RO]{\thepage}
\fancyhead[RE]{\textit{Letters of Solar Influences on the Magnetosphere, Ionosphere and Atmosphere}}
\fancyhead[LO]{Year of publication: XXXX, Number of pages: XX, DOI: 10.31401/XXXX}

% Title format
\titleformat{\section}[block]{\bfseries\large}{\thesection}{1em}{}
\titleformat{\subsection}[block]{\bfseries}{\thesubsection}{1em}{}

% Custom title
\renewcommand{\maketitle}{
    \begingroup
    \centering
    \vspace*{1cm}
    \bfseries\LARGE \@title \par
    \vspace{1cm}
    \normalsize \@author \par % Fix the typo here
    \vspace{0.5cm}
    \small \@affiliations \par
    \vspace{0.5cm}
    \normalsize \@corresponding \par
    \vspace{1cm}
    \begin{center}
        \begin{minipage}{0.8\textwidth}
            \bfseries Abstract \\
            \normalfont\small \@abstract \par
        \end{minipage}
    \end{center}
    \vspace{1cm}
    \endgroup
}

% Abstract command
\newcommand{\setabstract}[1]{\def\@abstract{#1}}

% Author and affiliation commands
\newcommand{\setaffiliations}[1]{\def\@affiliations{#1}}

% Corresponding author email command
\newcommand{\setcorresponding}[1]{\def\@corresponding{#1}}

\endinput
